==> freej-0.1.tar.gz: freej-0.1/src/include/v4l.h <==
/*  FreeJ
 *  (c) Copyright 2001 Denis Roio aka jaromil <jaromil@dyne.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __v4l_h__
#define __v4l_h_

/* this to avoid g++ complaining about videodev.h */
#define ulong __u32

#include <linux/types.h>
#include <linux/videodev.h>
#include <SDL_thread.h>
#include <layer.h>

class V4lGrabber: public Layer {
 private:
  int dev;
  int input;
  int norm;
  Uint32 palette;

  struct video_capability grab_cap;

  struct video_mbuf grab_map;
  struct video_mmap grab_buf[2];
  int cur_frame;
  int ok_frame;
  int num_frame;

  struct video_channel grab_chan;
  struct video_picture grab_pic;

  bool grab24;
  bool have_tuner;
  int minw, minh, maxw, maxh;

  unsigned char *get_buffer();

 public:
  V4lGrabber();
  ~V4lGrabber();
  bool detect(char *devfile);
  bool init(Context *screen, int wdt, int hgt, int dpt);
  bool feed();
  bool blit(unsigned char *dest);

  unsigned char *buffer;
  char *device;

};

#endif

==> freej-0.1.2.tar.gz: freej-0.1.2/src/include/v4l.h <==
/*  FreeJ
 *  (c) Copyright 2001 Denis Roio aka jaromil <jaromil@dyne.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __v4l_h__
#define __v4l_h_

/* this to avoid g++ complaining about videodev.h */
#define ulong __u32

#include <linux/types.h>
#include <linux/videodev.h>
#include <SDL_thread.h>
#include <layer.h>

class V4lGrabber: public Layer {
 private:
  int dev;
  int input;
  int norm;
  Uint32 palette;

  struct video_capability grab_cap;

  struct video_mbuf grab_map;
  struct video_mmap grab_buf[2];
  int cur_frame;
  int ok_frame;
  int num_frame;

  struct video_channel grab_chan;
  struct video_picture grab_pic;

  bool grab24;
  bool have_tuner;
  int minw, minh, maxw, maxh;

  void *get_buffer();

 public:
  V4lGrabber();
  ~V4lGrabber();
  bool detect(char *devfile);
  bool init(Context *screen, int wdt, int hgt);
  bool feed();
  bool blit(unsigned char *dest);

  unsigned char *buffer;
  char *device;

};

#endif
